@@ -42,14 +42,14 @@ QDebug operator<<(QDebug dbg, const Coordinates &coordinates)
 
 QPair<Coordinates, Coordinates> Coordinates::boundingRect(qreal distance) const
 {
-	qreal radDist = distance / WGS84_RADIUS;
+	double radDist = distance / WGS84_RADIUS;
 
-	qreal minLat = deg2rad(_lat) - radDist;
-	qreal maxLat = deg2rad(_lat) + radDist;
+	double minLat = deg2rad(_lat) - radDist;
+	double maxLat = deg2rad(_lat) + radDist;
 
-	qreal minLon, maxLon;
+	double minLon, maxLon;
 	if (minLat > MIN_LAT && maxLat < MAX_LAT) {
-		qreal deltaLon = asin(sin(radDist) / cos(_lat));
+		double deltaLon = asin(sin(radDist) / cos(_lat));
 		minLon = deg2rad(_lon) - deltaLon;
 		if (minLon < MIN_LON)
 			minLon += 2.0 * M_PI;
@@ -58,10 +58,8 @@ QPair<Coordinates, Coordinates> Coordinates::boundingRect(qreal distance) const
 			maxLon -= 2.0 * M_PI;
 	} else {
 		// a pole is within the distance
-        double dminLat=minLat;
-        double dmaxLat=maxLat;
-        minLat = qMax(dminLat, MIN_LAT);
-        maxLat = qMin(dmaxLat, MAX_LAT);
+		minLat = qMax(minLat, MIN_LAT);
+		maxLat = qMin(maxLat, MAX_LAT);
 		minLon = MIN_LON;
 		maxLon = MAX_LON;
 	}
