@@ -203,7 +203,6 @@ void GUI::ShowContextMenu(const QPoint &pos)
    contextMenu.exec(mapToGlobal(pos));
 }
 #endif
-
 const QString GUI::fileFormats() const
 {
 	return tr("Supported files (*.csv *.fit *.gpx *.igc *.kml *.nmea *.tcx)")
@@ -243,8 +242,15 @@ void GUI::loadPOIs()
 	else
 		list = globalDir.entryInfoList(QStringList(), QDir::Files);
 
-	for (int i = 0; i < list.size(); ++i)
-		_poi->loadFile(list.at(i).absoluteFilePath());
+	for (int i = 0; i < list.size(); ++i) {
+		if (!_poi->loadFile(list.at(i).absoluteFilePath())) {
+			fprintf(stderr, "Error loading POI file: %s: %s\n",
+			  qPrintable(list.at(i).fileName()),
+			  qPrintable(_poi->errorString()));
+			if (_poi->errorLine())
+				fprintf(stderr, "Line: %d\n", _poi->errorLine());
+		}
+	}
 }
 
 void GUI::createMapActions()
@@ -331,19 +337,17 @@ void GUI::createActions()
 	_openFileAction->setShortcut(OPEN_SHORTCUT);
 	connect(_openFileAction, SIGNAL(triggered()), this, SLOT(openFile()));
 	addAction(_openFileAction);
-
-    /*_printFileAction = new QAction(QIcon(QPixmap(PRINT_FILE_ICON)),
+	/*_printFileAction = new QAction(QIcon(QPixmap(PRINT_FILE_ICON)),
 	  tr("Print..."), this);
 	_printFileAction->setActionGroup(_fileActionGroup);
 	connect(_printFileAction, SIGNAL(triggered()), this, SLOT(printFile()));
-    addAction(_printFileAction);*/
-
-    _exportFileAction = new QAction(QIcon(QPixmap(EXPORT_FILE_ICON)),
+	addAction(_printFileAction);*/
+	_exportFileAction = new QAction(QIcon(QPixmap(EXPORT_FILE_ICON)),
 	  tr("Export to PDF..."), this);
 	_exportFileAction->setShortcut(EXPORT_SHORTCUT);
 	_exportFileAction->setActionGroup(_fileActionGroup);
 	connect(_exportFileAction, SIGNAL(triggered()), this, SLOT(exportFile()));
-    addAction(_exportFileAction);
+	addAction(_exportFileAction);
 	_closeFileAction = new QAction(QIcon(QPixmap(CLOSE_FILE_ICON)),
 	  tr("Close"), this);
 	_closeFileAction->setShortcut(CLOSE_SHORTCUT);
@@ -544,6 +548,7 @@ void GUI::createPoiMenu()
     click();
 }
 #endif
+
 void GUI::createMenus()
 {
 #ifdef Q_WS_MAEMO_5
@@ -758,6 +763,7 @@ void GUI::about()
 	  + QString("<p>") + tr("Version ") + APP_VERSION + QString(" (")
 	  + CPU_ARCH + QString(", Qt ") + QString(QT_VERSION_STR)
 	  + QString(") for maemo by Halftux</p>"));
+
 	msgBox.setInformativeText(QString("<table width=\"300\"><tr><td>")
 	  + tr("GPXSee is distributed under the terms of the GNU General Public "
 	  "License version 3. For more info about GPXSee visit the project "
@@ -991,6 +997,7 @@ void GUI::closePOIFiles()
 	_poi->clear();
 }
 #ifndef Q_WS_MAEMO_5
+
 void GUI::printFile()
 {
 	QPrinter printer(QPrinter::HighResolution);
@@ -1007,7 +1014,7 @@ void GUI::openOptions()
 #ifdef Q_WS_MAEMO_5
     optDialog dialog(&options, this);
 #else
-    OptionsDialog dialog(&options, this);
+	OptionsDialog dialog(&options, this);
 #endif
 	if (dialog.exec() != QDialog::Accepted)
 		return;
@@ -1065,9 +1072,8 @@ void GUI::exportFile()
 	printer.setOrientation(_export.orientation);
 	printer.setOutputFileName(_export.fileName);
 	printer.setPaperSize(_export.paperSize);
-    printer.setPageMargins(_export.margins.left(), _export.margins.top(),
-      _export.margins.right(), _export.margins.bottom(), QPrinter::Millimeter);
-
+	printer.setPageMargins(_export.margins.left(), _export.margins.top(),
+	  _export.margins.right(), _export.margins.bottom(), QPrinter::Millimeter);
 
 	plot(&printer);
 }
@@ -1141,7 +1147,7 @@ void GUI::plot(QPrinter *printer)
 			if (_tabs.at(i)->count())
 				cnt++;
 
-        double sp = ratio * 20;
+		double sp = ratio * 20;
 		gh = qMin((printer->height() - ((cnt - 1) * sp))/(qreal)cnt,
 		  0.20 * printer->height());
 
@@ -1455,7 +1461,7 @@ void GUI::updatePathView()
 
 void GUI::setUnits(Units units)
 {
-    //_export.units = units;
+	_export.units = units;
 	_options.units = units;
 
 	_pathView->setUnits(units);
@@ -1555,7 +1561,7 @@ void GUI::closeEvent(QCloseEvent *event)
 
 void GUI::dragEnterEvent(QDragEnterEvent *event)
 {
-#if defined (Q_WS_MAEMO_5) || defined(Q_OS_HARMATTAN)
+    #ifdef Q_WS_MAEMO_5
         event->ignore();
     #else
 	if (!event->mimeData()->hasUrls())
@@ -1574,7 +1580,7 @@ void GUI::dragEnterEvent(QDragEnterEvent *event)
 
 void GUI::dropEvent(QDropEvent *event)
 {
-#if defined (Q_WS_MAEMO_5) || defined(Q_OS_HARMATTAN)
+#ifdef Q_WS_MAEMO_5
     event->ignore();
 #else
 	QList<QUrl> urls = event->mimeData()->urls();
@@ -1615,9 +1621,9 @@ void GUI::writeSettings()
 	settings.beginGroup(GRAPH_SETTINGS_GROUP);
 	if (_showGraphsAction->isChecked() != SHOW_GRAPHS_DEFAULT)
 		settings.setValue(SHOW_GRAPHS_SETTING, _showGraphsAction->isChecked());
-    if ((_timeGraphAction->isChecked() ? gtTime : gtDistance) != GRAPH_TYPE_DEFAULT)
+	if ((_timeGraphAction->isChecked() ? gtTime : gtDistance) != GRAPH_TYPE_DEFAULT)
 		settings.setValue(GRAPH_TYPE_SETTING, _timeGraphAction->isChecked()
-          ? gtTime : gtDistance);
+		  ? gtTime : gtDistance);
 	if (_showGraphGridAction->isChecked() != SHOW_GRAPH_GRIDS_DEFAULT)
 		settings.setValue(SHOW_GRAPH_GRIDS_SETTING,
 		  _showGraphGridAction->isChecked());
@@ -1658,7 +1664,7 @@ void GUI::writeSettings()
 		  _showRouteWaypointsAction->isChecked());
 	settings.endGroup();
 
-    settings.beginGroup(EXPORT_SETTINGS_GROUP);
+	settings.beginGroup(EXPORT_SETTINGS_GROUP);
 	if (_export.orientation != PAPER_ORIENTATION_DEFAULT)
 		settings.setValue(PAPER_ORIENTATION_SETTING, _export.orientation);
 	if (_export.paperSize != PAPER_SIZE_DEFAULT)
@@ -1673,7 +1679,7 @@ void GUI::writeSettings()
 		settings.setValue(MARGIN_BOTTOM_SETTING, _export.margins.bottom());
 	if (_export.fileName != EXPORT_FILENAME_DEFAULT)
 		settings.setValue(EXPORT_FILENAME_SETTING, _export.fileName);
-    settings.endGroup();
+	settings.endGroup();
 
 	settings.beginGroup(OPTIONS_SETTINGS_GROUP);
 	if (_options.palette.color() != PALETTE_COLOR_DEFAULT)
@@ -1756,7 +1762,7 @@ void GUI::readSettings()
 	else
 		_showGraphsAction->setChecked(true);
 	if (settings.value(GRAPH_TYPE_SETTING, GRAPH_TYPE_DEFAULT).toInt()
-      == gtTime) {
+	  == gtTime) {
 		setTimeGraph();
 		_timeGraphAction->setChecked(true);
 	} else
@@ -1826,7 +1832,7 @@ void GUI::readSettings()
 		_showRouteWaypointsAction->setChecked(true);
 	settings.endGroup();
 
-    settings.beginGroup(EXPORT_SETTINGS_GROUP);
+	settings.beginGroup(EXPORT_SETTINGS_GROUP);
 	_export.orientation = (QPrinter::Orientation) settings.value(
 	  PAPER_ORIENTATION_SETTING, PAPER_ORIENTATION_DEFAULT).toInt();
 	_export.paperSize = (QPrinter::PaperSize) settings.value(PAPER_SIZE_SETTING,
@@ -1841,7 +1847,7 @@ void GUI::readSettings()
 	_export.margins = MarginsF(ml, mt, mr, mb);
 	_export.fileName = settings.value(EXPORT_FILENAME_SETTING,
 	 EXPORT_FILENAME_DEFAULT).toString();
-    settings.endGroup();
+	settings.endGroup();
 
 	settings.beginGroup(OPTIONS_SETTINGS_GROUP);
 	QColor pc = settings.value(PALETTE_COLOR_SETTING, PALETTE_COLOR_DEFAULT)
