@@ -4,6 +4,7 @@
 #include <QSysInfo>
 #include "opengl.h"
 #include "rd.h"
+#include "wgs84.h"
 #include "poi.h"
 #include "data.h"
 #include "map.h"
@@ -23,21 +24,20 @@ static QPoint mercator2tile(const QPointF &m, int z)
 {
 	QPoint tile;
 
-	tile.setX((int)(floor((m.x() + 180.0) / 360.0 * pow(2.0, z))));
-	tile.setY((int)(floor((1.0 - (m.y() / 180.0)) / 2.0 * pow(2.0, z))));
+	tile.setX((int)(floor((m.x() + 180.0) / 360.0 * (1<<z))));
+	tile.setY((int)(floor((1.0 - (m.y() / 180.0)) / 2.0 * (1<<z))));
 
 	return tile;
 }
 
 static QPointF tile2mercator(const QPoint &tile, int z)
 {
-	Coordinates m;
+	QPointF m;
 
-	m.setLon(tile.x() / pow(2.0, z) * 360.0 - 180);
-	qreal n = M_PI - 2.0 * M_PI * tile.y() / pow(2.0, z);
-	m.setLat(rad2deg(atan(0.5 * (exp(n) - exp(-n)))));
+	m.setX(((360.0 * tile.x()) / (qreal)(1<<z)) - 180.0);
+	m.setY((1.0 - (2.0 * tile.y()) / (qreal)(1<<z)) * 180.0);
 
-	return m.toMercator();
+	return m;
 }
 
 static int scale2zoom(qreal scale)
@@ -57,10 +57,15 @@ qreal mapScale(int zoom)
 	return ((360.0/(qreal)(1<<zoom))/(qreal)Tile::size());
 }
 
-static QRectF qrectf(const QPointF &p1, const QPointF &p2)
+static QRectF mapBounds()
 {
-	return QRectF(QPointF(qMin(p1.x(), p2.x()), qMin(p1.y(), p2.y())),
-	  QPointF(qMax(p1.x(), p2.x()), qMax(p1.y(), p2.y())));
+	return QRectF(QPointF(-180, -180), QSizeF(360, 360));
+}
+
+static qreal zoom2resolution(int zoom, qreal y)
+{
+	return (WGS84_RADIUS * 2 * M_PI / Tile::size()
+	  * cos(2.0 * atan(exp(deg2rad(y))) - M_PI/2)) / (qreal)(1<<zoom);
 }
 
 static void unite(QRectF &rect, const QPointF &p)
@@ -99,6 +104,7 @@ PathView::PathView(QWidget *parent)
 	_mapScale->setZValue(2.0);
 
 	_zoom = ZOOM_MAX;
+	_res = 1.0;
 	_map = 0;
 	_poi = 0;
 
@@ -118,6 +124,8 @@ PathView::PathView(QWidget *parent)
 	_routeStyle = Qt::DashLine;
 
 	_plot = false;
+
+	_scene->setSceneRect(scaled(mapBounds(), 1.0 / mapScale(_zoom)));
 }
 
 PathView::~PathView()
@@ -184,21 +192,13 @@ void PathView::addWaypoints(const QList<Waypoint> &waypoints)
 		const Waypoint &w = waypoints.at(i);
 
 		WaypointItem *wi = new WaypointItem(w);
+		_waypoints.append(wi);
+		updateWaypointsBoundingRect(wi->coordinates());
 		wi->setScale(1.0/scale);
 		wi->setZValue(1);
 		wi->showLabel(_showWaypointLabels);
 		wi->setVisible(_showWaypoints);
 		_scene->addItem(wi);
-
-		if (_wr.isNull()) {
-			if (_wp.isNull())
-				_wp = wi->coordinates();
-			else
-				_wr = qrectf(_wp, wi->coordinates());
-		} else
-			unite(_wr, wi->coordinates());
-
-		_waypoints.append(wi);
 	}
 
 	if (_poi)
@@ -215,33 +215,49 @@ QList<PathItem *> PathView::loadData(const Data &data)
 
 	for (int i = 0; i < data.tracks().count(); i++)
 		paths.append(addTrack(*(data.tracks().at(i))));
+
 	for (int i = 0; i < data.routes().count(); i++)
 		paths.append(addRoute(*(data.routes().at(i))));
+
 	addWaypoints(data.waypoints());
 
 	if (_tracks.empty() && _routes.empty() && _waypoints.empty())
 		return paths;
 
-	if ((_tracks.size() + _routes.size() > 1 && _zoom < zoom)
-	  || (_waypoints.size() && _zoom < zoom))
+	if (_zoom < zoom)
 		rescale(_zoom);
 	else
 		updatePOIVisibility();
 
-	QRectF sr = contentsSceneRect();
-	_scene->setSceneRect(sr);
-	centerOn(sr.center());
+	QPointF center = contentsCenter();
+	centerOn(center);
 
-	_mapScale->setZoom(_zoom, -(sr.center().ry() * mapScale(_zoom)));
+	_res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
+	_mapScale->setResolution(_res);
 	if (_mapScale->scene() != _scene)
 		_scene->addItem(_mapScale);
 
 	return paths;
 }
 
+void PathView::updateWaypointsBoundingRect(const QPointF &wp)
+{
+	if (_wr.isNull()) {
+		if (_wp.isNull())
+			_wp = wp;
+		else {
+			_wr = QRectF(_wp, wp).normalized();
+			_wp = QPointF();
+		}
+	} else
+		unite(_wr, wp);
+}
+
 qreal PathView::contentsScale() const
 {
 	QRectF br = _tr | _rr | _wr;
+	if (!br.isNull() && !_wp.isNull())
+		unite(br, _wp);
 
 	if (br.isNull())
 		return mapScale(ZOOM_MAX);
@@ -252,17 +268,18 @@ qreal PathView::contentsScale() const
 	return qMax(sc.x(), sc.y());
 }
 
-QRectF PathView::contentsSceneRect() const
+QPointF PathView::contentsCenter() const
 {
+	QRectF br = _tr | _rr | _wr;
+	if (!br.isNull() && !_wp.isNull())
+		unite(br, _wp);
+
 	qreal scale = mapScale(_zoom);
-	QRectF br = scaled(_tr | _rr | _wr, 1.0/scale);
 
 	if (br.isNull())
-		return QRectF(QPointF(_wp.x() / scale - Tile::size()/2,
-		  _wp.y() /scale - Tile::size()/2), QSizeF(Tile::size(), Tile::size()));
+		return _wp / scale;
 	else
-		return br.adjusted(-Tile::size(), -Tile::size(), Tile::size(),
-		  Tile::size());
+		return scaled(br, 1.0/scale).center();
 }
 
 void PathView::updatePOIVisibility()
@@ -291,6 +308,8 @@ void PathView::rescale(int zoom)
 	_zoom = zoom;
 	qreal scale = mapScale(zoom);
 
+	_scene->setSceneRect(scaled(mapBounds(), 1.0 / scale));
+
 	for (int i = 0; i < _tracks.size(); i++)
 		_tracks.at(i)->setScale(1.0/scale);
 
@@ -410,16 +429,6 @@ void PathView::redraw()
 	resetCachedContent();
 }
 
-void PathView::rescale()
-{
-	int zoom = scale2zoom(contentsScale());
-
-	if (zoom != _zoom) {
-		rescale(zoom);
-		_mapScale->setZoom(zoom);
-	}
-}
-
 void PathView::zoom(int z, const QPoint &pos)
 {
 	if (_tracks.isEmpty() && _routes.isEmpty() && _waypoints.isEmpty())
@@ -433,16 +442,12 @@ void PathView::zoom(int z, const QPoint &pos)
 
 	rescale(_zoom);
 
-	QRectF sr = contentsSceneRect();
-	_scene->setSceneRect(sr);
+	QPointF center = (spos * (os/mapScale(_zoom))) - offset;
+	centerOn(center);
 
-	if (sr.width() < viewport()->size().width()
-	  && sr.height() < viewport()->size().height())
-		centerOn(sr.center());
-	else
-		centerOn((spos * (os/mapScale(_zoom))) - offset);
+	_res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
+	_mapScale->setResolution(_res);
 
-	_mapScale->setZoom(_zoom);
 
 	resetCachedContent();
 }
@@ -465,7 +470,6 @@ void PathView::mouseDoubleClickEvent(QMouseEvent *event)
 
 	zoom(z, event->pos());
 }
-
 #ifdef Q_WS_MAEMO_5
 void PathView::mousePressEvent(QMouseEvent *e)
 {
@@ -545,10 +549,11 @@ void PathView::clear()
 	_palette.reset();
 
 	_zoom = ZOOM_MAX;
+	_res = 1.0;
 	_tr = QRectF(); _rr = QRectF(); _wr = QRectF();
 	_wp = QPointF();
 
-	_scene->setSceneRect(QRectF());
+	_scene->setSceneRect(scaled(mapBounds(), 1.0 / mapScale(_zoom)));
 }
 
 void PathView::showTracks(bool show)
@@ -668,15 +673,14 @@ void PathView::drawBackground(QPainter *painter, const QRectF &rect)
 	QPoint tile = mercator2tile(QPointF(rr.topLeft().x(), -rr.topLeft().y()),
 	  _zoom);
 	QPointF tm = tile2mercator(tile, _zoom);
-	QPoint tl = mapToScene(mapFromScene(QPointF(tm.x() / scale,
-	  -tm.y() / scale))).toPoint();
+	QPoint tl = QPoint((int)(tm.x() / scale), (int)(-tm.y() / scale));
+
 
 	QList<Tile> tiles;
-	for (int i = 0; i <= rr.size().width() / Tile::size() + 1; i++) {
-		for (int j = 0; j <= rr.size().height() / Tile::size() + 1; j++) {
+	QSizeF s(rect.right() - tl.x(), rect.bottom() - tl.y());
+	for (int i = 0; i < ceil(s.width() / Tile::size()); i++)
+		for (int j = 0; j < ceil(s.height() / Tile::size()); j++)
 			tiles.append(Tile(QPoint(tile.x() + i, tile.y() + j), _zoom));
-		}
-	}
 
 	_map->loadTiles(tiles, _plot);
 
@@ -690,24 +694,21 @@ void PathView::drawBackground(QPainter *painter, const QRectF &rect)
 
 void PathView::resizeEvent(QResizeEvent *event)
 {
+	Q_UNUSED(event);
+
 	if (_tracks.isEmpty() && _routes.isEmpty() && _waypoints.isEmpty())
 		return;
 
-	rescale();
+	int zoom = scale2zoom(contentsScale());
+	if (zoom != _zoom)
+		rescale(zoom);
 
-	QRectF sr = contentsSceneRect();
+	QPointF center = contentsCenter();
+	centerOn(center);
 
-	if (sr.width() < event->size().width()) {
-		qreal diff = event->size().width() - sr.width();
-		sr.adjust(-diff/2, 0, diff/2, 0);
-	}
-	if (sr.height() < event->size().height()) {
-		qreal diff = event->size().height() - sr.height();
-		sr.adjust(0, -diff/2, 0, diff/2);
-	}
+	_res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
+	_mapScale->setResolution(_res);
 
-	_scene->setSceneRect(sr);
-	centerOn(sr.center());
 
 	resetCachedContent();
 }
@@ -723,13 +724,26 @@ void PathView::paintEvent(QPaintEvent *event)
 	QGraphicsView::paintEvent(event);
 }
 
+void PathView::scrollContentsBy(int dx, int dy)
+{
+	QGraphicsView::scrollContentsBy(dx, dy);
+
+	QPointF center = mapToScene(viewport()->rect().center());
+	qreal res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
+
+	if (qMax(res, _res) / qMin(res, _res) > 1.1) {
+		_mapScale->setResolution(res);
+		_res = res;
+	}
+}
+
 void PathView::useOpenGL(bool use)
 {
 	if (use) {
 #ifdef Q_OS_WIN32
 		if (QSysInfo::WindowsVersion >= QSysInfo::WV_VISTA)
 #endif // Q_OS_WIN32
-	setViewport(new OPENGL_WIDGET);
+		setViewport(new OPENGL_WIDGET);
 	} else
 		setViewport(new QWidget);
 }
